<?php


namespace Drupal\reaction\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\reaction\Entity\ReactionEntity;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;

/**
 * Reaction controller for the ajax_link module.
 */
class ReactionController extends ControllerBase {


  public function ajax_link_response($url_encode_data) {
    global $base_url;
    $module_path = drupal_get_path('module', 'reaction');
    $decode_data = json_decode(ReactionController::base64url_decode($url_encode_data));
    $entity_type = $decode_data->entity_type;
    $bundle = $decode_data->bundle;
    $entity_id = $decode_data->entity_id;
    $expression = $decode_data->expression;
    $ip = $decode_data->ip;
    $reaction_emoji_display = (array)$decode_data->reaction_emoji_display;
    $style_setting = $decode_data->style_setting;
    $layout_style = $decode_data->layout_style;
    $user_id = \Drupal::currentUser()->id();
    $reaction = ReactionEntity::create(
      [
        'entity_id' => $entity_id,
        'ip_address' => $ip,
        'entity_type' => $entity_type,
        'bundle' => $bundle,
        'value' => $expression,
        'user_id' => $user_id,
      ]
    );
    $reaction->save();
    //after inserting setting reacted to true
    $reacted = TRUE;
    $user_reacted_emoji_class = 'user_reacted_emoji';
    //To get the total count which we are using in calculate percentage
    $total_count = ReactionController::get_emoji_total_count($reaction_emoji_display, $entity_id);
    foreach ($reaction_emoji_display as $emoji) {
      $count = ReactionController::_get_count_reaction($entity_id, $emoji);
      $percentage_calculate = 100 / $total_count;
      if (!is_numeric($emoji)) {
        $image[] = array(
          'image_path' => $base_url . '/' . $module_path . '/vendor/krknth/reaction/' . $style_setting . '/' . $emoji . '.png',
          'emoji_name' => $emoji,
          'user_reacted_emoji' => $user_reacted_emoji_class,
          'percentage' => is_nan(round($count * $percentage_calculate)) ? 0 : round($count * $percentage_calculate),
          'reacted_count' => $count,
        );
      }
    }
    $elements[] = array(
      '#theme' => 'reaction_formatter',
      '#style' => $style_setting,
      '#image' => $image,
      '#layout_style' => $layout_style,
      '#reacted' => $reacted,
    );
    $ajax_response = new AjaxResponse();
    $value = $ajax_response->addCommand(new ReplaceCommand('#reaction-wrapper', $elements));
    return $value;
  }

  // Checks if already reacted or not
  function checking_reacted($entity_id, $user_id, $ip_address) {
    $query = \Drupal::entityQuery('reaction_entity');
    $query->condition('entity_id', $entity_id);
    $query->condition('user_id', $user_id);
    $query->condition('ip_address', $ip_address);
    return $query->execute();
  }

  // Get the reaction count based on entity id
  function _get_count_reaction($entity_id, $emoji) {
    $query = \Drupal::entityQuery('reaction_entity');
    $query->condition('entity_id', $entity_id);
    $query->condition('value', $emoji);
    $result = $query->execute();
    return count($result);
  }

  //To get the total count which we are using in calculate percentage
  function get_emoji_total_count($reaction_emoji_display, $entity_id) {
    $total_count = 0;
    foreach ($reaction_emoji_display as $emoji) {
      $count = ReactionController::_get_count_reaction($entity_id, $emoji);
      $total_count +=$count;
    }
    return $total_count;
  }
  
  // Base64 encode function
  function base64url_encode($string) {
    $base64 = base64_encode($string);
    $base64url = strtr($base64, '+/=', '-_,');
    return $base64url;
  }
  // Base64 decode function
  function base64url_decode($string) {
    $base64url = strtr($string, '-_,', '+/=');
    $base64 = base64_decode($base64url);
    return $base64;
  }

}
