<?php

namespace Drupal\reaction\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\RevisionLogInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Reaction entity entities.
 *
 * @ingroup reaction
 */
interface ReactionEntityInterface extends ContentEntityInterface, RevisionLogInterface, EntityChangedInterface, EntityOwnerInterface {

  // Add get/set methods for your configuration properties here.

  /**
   * Gets the Reaction entity name.
   *
   * @return string
   *   Name of the Reaction entity.
   */
  public function getName();

  /**
   * Sets the Reaction entity name.
   *
   * @param string $name
   *   The Reaction entity name.
   *
   * @return \Drupal\reaction\Entity\ReactionEntityInterface
   *   The called Reaction entity entity.
   */
  public function setName($name);

  /**
   * Gets the Reaction entity creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Reaction entity.
   */
  public function getCreatedTime();

  /**
   * Sets the Reaction entity creation timestamp.
   *
   * @param int $timestamp
   *   The Reaction entity creation timestamp.
   *
   * @return \Drupal\reaction\Entity\ReactionEntityInterface
   *   The called Reaction entity entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Reaction entity published status indicator.
   *
   * Unpublished Reaction entity are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Reaction entity is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Reaction entity.
   *
   * @param bool $published
   *   TRUE to set this Reaction entity to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\reaction\Entity\ReactionEntityInterface
   *   The called Reaction entity entity.
   */
  public function setPublished($published);

  /**
   * Gets the Reaction entity revision creation timestamp.
   *
   * @return int
   *   The UNIX timestamp of when this revision was created.
   */
  public function getRevisionCreationTime();

  /**
   * Sets the Reaction entity revision creation timestamp.
   *
   * @param int $timestamp
   *   The UNIX timestamp of when this revision was created.
   *
   * @return \Drupal\reaction\Entity\ReactionEntityInterface
   *   The called Reaction entity entity.
   */
  public function setRevisionCreationTime($timestamp);

  /**
   * Gets the Reaction entity revision author.
   *
   * @return \Drupal\user\UserInterface
   *   The user entity for the revision author.
   */
  public function getRevisionUser();

  /**
   * Sets the Reaction entity revision author.
   *
   * @param int $uid
   *   The user ID of the revision author.
   *
   * @return \Drupal\reaction\Entity\ReactionEntityInterface
   *   The called Reaction entity entity.
   */
  public function setRevisionUserId($uid);

}
