<?php

namespace Drupal\reaction\Plugin\Field\FieldType;

use Drupal\Component\Utility\Random;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Plugin implementation of the 'reaction' field type.
 *
 * @FieldType(
 *   id = "reaction",
 *   label = @Translation("Reaction"),
 *   default_formatter = "reaction_formatter",
 *   default_widget = "reaction_default",
 *   description = @Translation("Adding reaction field type") * )
 */
class ReactionItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    return [
      'reaction_style' => ['smiling-face-with-sunglasses', 'white-smiling-face']
      ] + parent::defaultStorageSettings();
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    // Prevent early t() calls by using the TranslatableMarkup.
    $properties['value'] = DataDefinition::create('string')
      ->setLabel(new TranslatableMarkup('Text value'))
      ->setSetting('case_sensitive', $field_definition->getSetting('case_sensitive'))
      ->setRequired(TRUE);

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    $schema = [
      'columns' => [
        'value' => [
          'type' => $field_definition->getSetting('is_ascii') === TRUE ? 'varchar_ascii' : 'varchar',
          'length' => (int) $field_definition->getSetting('max_length'),
          'binary' => $field_definition->getSetting('case_sensitive'),
        ],
      ],
    ];

    return $schema;
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    global $base_url;
    $element = [];
    $path = drupal_get_path('module', 'reaction');
    if ($handle = opendir($path . '/vendor/krknth/reaction/google')) {
      while (false !== ($entry = readdir($handle))) {
        if ($entry != "." && $entry != "..") {
          $reaction_name = substr($entry, 0, strpos($entry, "."));
          $reaction_style_option[$reaction_name] = '<img src = ' . $base_url . '/' . $path . '/vendor/krknth/reaction/google/' . $reaction_name . '.png';
        }
      }
      closedir($handle);
    }
    $element['reaction_style'] = [
      '#type' => 'checkboxes',
      '#title' => t('Select your emoji'),
      '#options' => $reaction_style_option,
      '#default_value' => $this->getSetting('reaction_style'),
    ];
    $element['#attached']['library'][] = 'core/drupal.ajax';
    $element['#attached']['library'][] = 'reaction/reaction';
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('value')->getValue();
    return $value === NULL || $value === '';
  }

}
