<?php

namespace Drupal\reaction;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the Reaction entity entity.
 *
 * @see \Drupal\reaction\Entity\ReactionEntity.
 */
class ReactionEntityAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    /** @var \Drupal\reaction\Entity\ReactionEntityInterface $entity */
    switch ($operation) {
      case 'view':
        if (!$entity->isPublished()) {
          return AccessResult::allowedIfHasPermission($account, 'view unpublished reaction entity entities');
        }
        return AccessResult::allowedIfHasPermission($account, 'view published reaction entity entities');

      case 'update':
        return AccessResult::allowedIfHasPermission($account, 'edit reaction entity entities');

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'delete reaction entity entities');
    }

    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add reaction entity entities');
  }

}
