<?php

namespace Drupal\reaction;

use Drupal\Core\Entity\Sql\SqlContentEntityStorage;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Language\LanguageInterface;
use Drupal\reaction\Entity\ReactionEntityInterface;

/**
 * Defines the storage handler class for Reaction entity entities.
 *
 * This extends the base storage class, adding required special handling for
 * Reaction entity entities.
 *
 * @ingroup reaction
 */
class ReactionEntityStorage extends SqlContentEntityStorage implements ReactionEntityStorageInterface {

  /**
   * {@inheritdoc}
   */
  public function revisionIds(ReactionEntityInterface $entity) {
    return $this->database->query(
      'SELECT vid FROM {reaction_entity_revision} WHERE id=:id ORDER BY vid',
      [':id' => $entity->id()]
    )->fetchCol();
  }

  /**
   * {@inheritdoc}
   */
  public function userRevisionIds(AccountInterface $account) {
    return $this->database->query(
      'SELECT vid FROM {reaction_entity_field_revision} WHERE uid = :uid ORDER BY vid',
      [':uid' => $account->id()]
    )->fetchCol();
  }

  /**
   * {@inheritdoc}
   */
  public function countDefaultLanguageRevisions(ReactionEntityInterface $entity) {
    return $this->database->query('SELECT COUNT(*) FROM {reaction_entity_field_revision} WHERE id = :id AND default_langcode = 1', [':id' => $entity->id()])
      ->fetchField();
  }

  /**
   * {@inheritdoc}
   */
  public function clearRevisionsLanguage(LanguageInterface $language) {
    return $this->database->update('reaction_entity_revision')
      ->fields(['langcode' => LanguageInterface::LANGCODE_NOT_SPECIFIED])
      ->condition('langcode', $language->getId())
      ->execute();
  }

}
