<?php

namespace Drupal\reaction;

use Drupal\Core\Entity\ContentEntityStorageInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Language\LanguageInterface;
use Drupal\reaction\Entity\ReactionEntityInterface;

/**
 * Defines the storage handler class for Reaction entity entities.
 *
 * This extends the base storage class, adding required special handling for
 * Reaction entity entities.
 *
 * @ingroup reaction
 */
interface ReactionEntityStorageInterface extends ContentEntityStorageInterface {

  /**
   * Gets a list of Reaction entity revision IDs for a specific Reaction entity.
   *
   * @param \Drupal\reaction\Entity\ReactionEntityInterface $entity
   *   The Reaction entity entity.
   *
   * @return int[]
   *   Reaction entity revision IDs (in ascending order).
   */
  public function revisionIds(ReactionEntityInterface $entity);

  /**
   * Gets a list of revision IDs having a given user as Reaction entity author.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user entity.
   *
   * @return int[]
   *   Reaction entity revision IDs (in ascending order).
   */
  public function userRevisionIds(AccountInterface $account);

  /**
   * Counts the number of revisions in the default language.
   *
   * @param \Drupal\reaction\Entity\ReactionEntityInterface $entity
   *   The Reaction entity entity.
   *
   * @return int
   *   The number of revisions in the default language.
   */
  public function countDefaultLanguageRevisions(ReactionEntityInterface $entity);

  /**
   * Unsets the language for all Reaction entity with the given language.
   *
   * @param \Drupal\Core\Language\LanguageInterface $language
   *   The language object.
   */
  public function clearRevisionsLanguage(LanguageInterface $language);

}
